.BG
.FN bkde2D
.TL
Compute a 2D Binned Kernel Density Estimate
.DN
Returns the set of grid points in each coordinate direction,
and the matrix of density estimates over the mesh induced by
the grid points. The kernel is the standard bivariate normal
density. 
.CS
bkde2D(x, bandwidth, gridsize=c(51, 51), range.x=<<see below>>, 
       truncate=T)
.RA
.AG x
a two-column matrix containing the observations from the  
distribution whose density is to be estimated.
Missing values are not allowed.
.AG bandwidth
vector containing the bandwidth to be used in each coordinate
direction.
.OA
.AG gridsize
vector containing the number of equally spaced points in each direction
over which the density is to be estimated.
.AG range.x
a list containing two vectors, where each vector 
contains the minimum and maximum values of x
at which to compute the estimate for each direction.
The default minimum in each direction is minimum
data value minus 1.5 times the bandwidth for
that direction. The default maximum is the maximum
data value plus 1.5 times the bandwidth for
that direction
.AG truncate
logical flag: if TRUE, data with x values outside the
range specified by range.x are ignored.
.RT
a list containing the following components:
.RC x1 
vector of values of the grid points in the first coordinate
direction at which the estimate was computed. 
.RC x2 
vector of values of the grid points in the second coordinate
direction at which the estimate was computed. 
.RC fhat
matrix of density estimates 
over the mesh induced by `x1' and `x2'.
.DT
This is the binned approximation to the 2D kernel density estimate.
Linear binning is used to obtain the bin counts and the
Fast Fourier Transform is used to perform the discrete convolutions.
For each `x1',`x2' pair the bivariate Gaussian kernel is
centered on that location and the heights of the 
kernel, scaled by the bandwidths, at each datapoint are summed.
This sum, after a normalization, is the corresponding 
`fhat' value in the output.
.SH REFERENCES
Wand, M. P. (1994).
Fast Computation of Multivariate Kernel Estimators.
.ul
Journal of Computational and Graphical Statistics,
3, 433-445.
.PP
Wand, M. P. and Jones, M. C. (1995).
.ul
Kernel Smoothing.
Chapman and Hall, London.
.SA
`bkde', `density', `hist', `ksmooth'.
.EX
x <- cbind(geyser$duration,geyser$waiting)
est <- bkde2D(x,bandwidth=c(0.7,7))
contour(est$x1,est$x2,est$fhat)
persp(est$fhat)
.KW smooth 
.WR
